@@ -6,8 +6,8 @@
 
 #include "collectionattributespage.h"
 
-#include <AkonadiCore/attributefactory.h>
-#include <AkonadiCore/collection.h>
+#include <Akonadi/AttributeFactory>
+#include <Akonadi/Collection>
 
 #include <QStandardItemModel>
 
